#t-loading-spinner {
    position:fixed;
    z-index:10000;
    background-position: center center;
    top:50%;
    left:50%;
    margin-top:-32px;
    margin-left:-32px;
}
.modal-footer button.close {
    background-image:linear-gradient(to bottom, #fff 0%, #e0e0e0 100%);
    background-repeat:repeat-x;
    border:#ccc 1px solid;
    padding:6px 12px;
    font-size:14px;
    font-weight:normal;
    line-height:1.42857;
    opacity:1;
}
.modal.info .modal-body,
.modal.warning .modal-body,
.modal.error .modal-body,
.modal.dialog .modal-body {
    padding-left:14px;
    min-height:80px;
}
.modal.info .modal-body:before,
.modal.warning .modal-body:before,
.modal.error .modal-body:before,
.modal.dialog .modal-body:before {
    top:2px;
    position:relative;
    display:inline-block;
    font-family:'Glyphicons Halflings';
    font-style:normal;
    font-weight:400;
    width:60px;
    height:60px;
    font-size:46px;
    line-height:46px;
    float:left;
}
.modal.info .modal-body:before {
    content:"";
}
.modal.warning .modal-body:before {
    content:"";
}
.modal.error .modal-body:before {
    content:"";
}
.modal.dialog .modal-body:before {
    content:"\e085";
}
